// Package gps provides different coordinate systems for reflecting locations on the earth surface.
package gps

// Type Coordinate holds GPS coordinate information.
type Coordinates struct {
	latitude  float64 `json:"latitude"`
	longitude float64 `json:"longitude"`
}

// Function CoordinatesWithLatLong creates Coordinates from given values.
// Values out of bounds will be set to the nearest boundary value.
func CoordinatesWithLatLong(lat float64, long float64) Coordinates {
	result := Coordinates{}
	result.SetLatitude(lat)
	result.SetLongitude(long)
	return result
}

// Method SetLongitude changes the longitude of the coordinate.
// If not -180 <= long <= 180.0 it will be set to nearest boundary value.
func (c *Coordinates) SetLongitude(long float64) {
	value := long
	if value < -180.0 {
		value = -180.0
	}
	if value > 180.0 {
		value = 180.0
	}
	c.longitude = value
}

func (c *Coordinates) Longitude() float64 {
	return c.longitude
}

// Method SetLatitude changes the latitude of the coordinate.
// If not -90.0 <= lat <= 90.0 it will be set to nearest boundary value.
func (c *Coordinates) SetLatitude(lat float64) {
	value := lat
	if value < -90.0 {
		value = -90.0
	}
	if value > 90.0 {
		value = 90.0
	}
	c.latitude = value
}

func (c *Coordinates) Latitude() float64 {
	return c.latitude
}
