package spacedata

import (
	"bytes"
	"encoding/json"
	"errors"
	"time"
)

type PassTimeProvider struct {
}

func (p PassTimeProvider) EndpointString() string {
	return "http://api.open-notify.org/iss-pass.json"
}

type Risings struct {
	Rising   int64 `json:"risetime"`
	Duration int64 `json:"duration"`
}

func (r Risings) IsoDateString() string {
	riseTime := time.Unix(r.Rising, 0)
	return riseTime.Format("2006-01-02T15:04:05-0700")
}

type risingTimes struct {
	Message string    `json:"message"`
	Risings []Risings `json:"response"`
}

func (p PassTimeProvider) ParseResponse(jsonData []byte) ([]byte, error) {
	if jsonData == nil || len(jsonData) == 0 {
		return nil, errors.New("empty or unset jsonData parameter")
	}

	temporaryResultValue := risingTimes{}

	decoder := json.NewDecoder(bytes.NewReader(jsonData))
	err := decoder.Decode(&temporaryResultValue)

	if err != nil {
		return nil, err
	}
	if temporaryResultValue.Message != "success" {
		return nil, errors.New("result json contains error message: " + temporaryResultValue.Message)
	}

	return temporaryResultValue.jsonData()
}

func (r risingTimes) jsonData() ([]byte, error) {
	return encodeJson(r.Risings)
}
